.. Copyright (C) 2025 @verzierf <francois.verzier@univ-grenoble-alpes.fr>

.. SPDX-License-Identifier: LGPL-3.0-or-later

.. _contributing:

============
Contributing
============

.. include:: ../../CONTRIBUTING.md
   :parser: myst_parser.sphinx_